@@ -2,6 +2,7 @@ from .cgnet import CGNet
 from .fast_scnn import FastSCNN
 from .hrnet import HRNet
 from .mobilenet_v2 import MobileNetV2
+from .mobilenet_v3 import MobileNetV3
 from .resnest import ResNeSt
 from .resnet import ResNet, ResNetV1c, ResNetV1d
 from .resnext import ResNeXt
@@ -9,5 +10,5 @@ from .unet import UNet
 
 __all__ = [
     'ResNet', 'ResNetV1c', 'ResNetV1d', 'ResNeXt', 'HRNet', 'FastSCNN',
-    'ResNeSt', 'MobileNetV2', 'UNet', 'CGNet'
+    'ResNeSt', 'MobileNetV2', 'UNet', 'CGNet', 'MobileNetV3'
 ]
